@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.10.0;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 $VERSION = eval $VERSION;
 use Pegex::Base;
 extends 'Pegex::Grammar';
@@ -12,7 +12,7 @@ use Log::Any '$log', filter => \&App::financeta::utils::log_filter;
 
 use constant text => <<GRAMMAR;
 %grammar financeta
-%version 0.15
+%version 0.16
 
 program: statement* end-of-program
 statement: comment | instruction | declaration
@@ -75,16 +75,20 @@ boolean: /((i:'true'|'false'))/
 GRAMMAR
 
 sub get_regexes {
-    return {
-        green => [qw(
-            buy sell negative positive zero below above long short
-        )],
-        blue => [qw(
+    my $conditions = [qw(
             at equals if when and or not is becomes crosses from to
             over into trades
-        )],
-        red => [qw(allow no true false)],
-        black => '(\$\w+)',
+        )];
+    my $keywords = [qw(
+            buy sell negative positive zero below above long short
+        )];
+    my $booleans = [qw(allow no true false)];
+    my $variables = '(\$\w+)';
+    return {
+        conditions => $conditions,
+        keywords => $keywords,
+        booleans => $booleans,
+        variables => $variables,
     };
 }
 
@@ -95,7 +99,7 @@ use strict;
 use warnings;
 use 5.10.0;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 $VERSION = eval $VERSION;
 use App::financeta::utils qw(log_filter);
 use Log::Any '$log', filter => \&App::financeta::utils::log_filter;
@@ -526,7 +530,7 @@ use strict;
 use warnings;
 use 5.10.0;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 $VERSION = eval $VERSION;
 use Pegex::Parser;
 use App::financeta::mo;
@@ -592,7 +596,7 @@ sub generate_coderef {
 1;
 
 __END__
-### COPYRIGHT: 2013-2023. Vikas N. Kumar. All Rights Reserved.
+### COPYRIGHT: 2013-2025. Vikas N. Kumar. All Rights Reserved.
 ### AUTHOR: Vikas N Kumar <vikas@cpan.org>
 ### DATE: 3rd Sept 2014
 ### LICENSE: Refer LICENSE file
